Crate hdf5_reader

Crate hdf5_reader 

Re-exports

pub use attribute_api::Attribute;
pub use cache::ChunkCacheStats;
pub use dataset::Dataset;
pub use dataset::DatasetChunk;
pub use dataset::DatasetChunkIterator;
pub use dataset::SliceInfo;
pub use dataset::SliceInfoElem;
pub use datatype_api::dtype_element_size;
pub use datatype_api::H5Type;
pub use filters::FilterRegistry;
pub use storage::BlockCacheStats;
pub use storage::BlockCacheStorage;
pub use storage::BytesStorage;
pub use storage::FileStorage;
pub use storage::MmapStorage;
pub use storage::RangeRequestStorage;
pub use storage::Storage;
pub use storage::StorageBuffer;

Modules

attribute_api
btree_v1
HDF5 B-link Tree Version 1.
btree_v2
HDF5 B-tree Version 2.
cache
checksum
chunk_index
Chunk indexing — resolves chunk locations from various storage strategies.
dataset
datatype_api
error
extensible_array
HDF5 Extensible Array (EA) chunk index.
filters
fixed_array
HDF5 Fixed Array (FA) chunk index.
fractal_heap
HDF5 Fractal Heap (FRHP).
global_heap
HDF5 Global Heap Collection (GCOL).
group
io
local_heap
HDF5 Local Heap (HEAP).
messages
HDF5 object header message parsing.
object_header
HDF5 Object Header parser (v1 and v2).
reference
HDF5 object reference resolution.
shared_message_table
Shared object-header message table (SOHM).
storage
superblock
symbol_table
HDF5 Symbol Table Entry and Symbol Table Node (SNOD).

Structs

CompoundField
A field within a compound datatype.
EnumMember
A member of an enumeration.
FilesystemExternalFileResolver
Filesystem resolver for external raw data files.
FilesystemExternalLinkResolver
Filesystem resolver for external links. Linked files are cached after the first successful open.
Hdf5File
An opened HDF5 file.
OpenOptions
Configuration options for opening an HDF5 file.

Enums

ByteOrder
Byte order for numeric data.
Datatype
Describes the element type of a dataset or attribute.
ReferenceType
HDF5 reference type.
StringEncoding
String character encoding.
StringPadding
String padding type.
StringSize
How a string’s length is determined.
VarLenKind
HDF5 variable-length datatype flavor.

Traits

ExternalFileResolver
Resolves file names from HDF5 External Data Files messages to storage.
ExternalLinkResolver
Resolves HDF5 external links to another opened file.

Type Aliases

HeaderCache
Cache for parsed object headers, keyed by file address.