pub struct ChunkCache { /* private fields */ }Expand description
LRU cache for decompressed chunks.
Thread-safe via parking_lot::Mutex (non-poisoning). Values are
Arc<Vec<u8>> so multiple readers can share the same decompressed chunk data.
Implementations
Sourceimpl ChunkCache
impl ChunkCache
Sourcepub fn new(max_bytes: usize, max_slots: usize) -> Self
pub fn new(max_bytes: usize, max_slots: usize) -> Self
Create a new chunk cache.
max_bytes: maximum total bytes of decompressed data to cache (default 64 MiB)max_slots: maximum number of entries (default 521)
Sourcepub fn get(&self, key: &ChunkKey) -> Option<Arc<Vec<u8>>>
pub fn get(&self, key: &ChunkKey) -> Option<Arc<Vec<u8>>>
Get a cached chunk, if present. Promotes the entry in LRU order.
Sourcepub fn insert(&self, key: ChunkKey, data: Vec<u8>) -> Arc<Vec<u8>> ⓘ
pub fn insert(&self, key: ChunkKey, data: Vec<u8>) -> Arc<Vec<u8>> ⓘ
Insert a chunk into the cache. Evicts LRU entries if over capacity.
Sourcepub fn get_or_insert_with<F>(
&self,
key: ChunkKey,
load: F,
) -> Result<Arc<Vec<u8>>>
pub fn get_or_insert_with<F>( &self, key: ChunkKey, load: F, ) -> Result<Arc<Vec<u8>>>
Return a cached chunk or compute it once across concurrent callers.
Sourcepub fn stats(&self) -> ChunkCacheStats
pub fn stats(&self) -> ChunkCacheStats
Return current cache statistics.