pub struct ExternalFileSlot {
pub name_offset: u64,
pub offset: u64,
pub size: u64,
}Expand description
A single external file slot.
Fields
name_offset: u64Offset into the local heap for the file name.
offset: u64Byte offset into the external file where data starts.
size: u64Number of bytes to read from the external file.