parse_message

Function parse_message 

pub fn parse_message(
    type_id: u16,
    msg_size: usize,
    cursor: &mut Cursor<'_>,
    offset_size: u8,
    length_size: u8,
) -> Result<HdfMessage>
Parse a single header message given its type ID, size, and a cursor positioned at the start of the message payload.

offset_size and length_size come from the superblock.