parse_old

Function parse_old 

pub fn parse_old(
    cursor: &mut Cursor<'_>,
    _offset_size: u8,
    _length_size: u8,
    msg_size: usize,
) -> Result<ModificationTimeMessage>
Parse the old modification time message (type 0x000E).

The old format stores a 14-character ASCII string “YYYYMMDDHHMMSS” but we just store the raw u32 value since the old format is rarely encountered in practice. If we get one, we attempt to parse or store 0.