Module shared

Module shared 

HDF5 Shared Message (Phase 2 stub).

A shared message indicates that the actual message content is stored elsewhere — either in another object header or in the shared message heap (SOHM).

Enums

SharedMessage
Where the shared message is stored.

Functions

parse
Parse a shared message wrapper.