Structs
- Bytes
Storage - In-memory storage backed by owned bytes.
- File
Storage - File-backed storage that serves explicit byte ranges via positional reads.
- Mmap
Storage - In-memory storage backed by a read-only memory map.
- Storage
Buffer - An immutable byte range returned by a storage backend.
Traits
- Storage
- Random-access, immutable byte storage for HDF5 parsing and reads.