Re-exports
pub use attribute_api::Attribute;pub use cache::ChunkCacheStats;pub use dataset::Dataset;pub use dataset::DatasetChunk;pub use dataset::DatasetChunkIterator;pub use dataset::SliceInfo;pub use dataset::SliceInfoElem;pub use datatype_api::dtype_element_size;pub use datatype_api::H5Type;pub use filters::FilterRegistry;pub use storage::BlockCacheStats;pub use storage::BlockCacheStorage;pub use storage::BytesStorage;pub use storage::FileStorage;pub use storage::MmapStorage;pub use storage::RangeRequestStorage;pub use storage::Storage;pub use storage::StorageBuffer;
Modules
- attribute_
api - btree_
v1 - HDF5 B-link Tree Version 1.
- btree_
v2 - HDF5 B-tree Version 2.
- cache
- checksum
- chunk_
index - Chunk indexing — resolves chunk locations from various storage strategies.
- dataset
- datatype_
api - error
- extensible_
array - HDF5 Extensible Array (EA) chunk index.
- filters
- fixed_
array - HDF5 Fixed Array (FA) chunk index.
- fractal_
heap - HDF5 Fractal Heap (FRHP).
- global_
heap - HDF5 Global Heap Collection (GCOL).
- group
- io
- local_
heap - HDF5 Local Heap (HEAP).
- messages
- HDF5 object header message parsing.
- object_
header - HDF5 Object Header parser (v1 and v2).
- reference
- HDF5 object reference resolution.
- shared_
message_ table - Shared object-header message table (SOHM).
- storage
- superblock
- symbol_
table - HDF5 Symbol Table Entry and Symbol Table Node (SNOD).
Structs
- Compound
Field - A field within a compound datatype.
- Enum
Member - A member of an enumeration.
- Filesystem
External File Resolver - Filesystem resolver for external raw data files.
- Filesystem
External Link Resolver - Filesystem resolver for external links. Linked files are cached after the first successful open.
- Hdf5
File - An opened HDF5 file.
- Open
Options - Configuration options for opening an HDF5 file.
Enums
- Byte
Order - Byte order for numeric data.
- Datatype
- Describes the element type of a dataset or attribute.
- Reference
Type - HDF5 reference type.
- String
Encoding - String character encoding.
- String
Padding - String padding type.
- String
Size - How a string’s length is determined.
- VarLen
Kind - HDF5 variable-length datatype flavor.
Traits
- External
File Resolver - Resolves file names from HDF5 External Data Files messages to storage.
- External
Link Resolver - Resolves HDF5 external links to another opened file.
Type Aliases
- Header
Cache - Cache for parsed object headers, keyed by file address.