HDF5 B-tree Version 2.
V2 B-trees are used by newer-style groups and datasets for indexed link
storage, attribute storage, and chunked dataset indexing. The header
(BTHD) describes the tree parameters. Internal nodes (BTIN) and leaf
nodes (BTLF) contain the actual records.
This module provides the header parse, record types, and a traversal function that collects all records from a tree.
Structs
- BTree
V2Header - Parsed B-tree v2 header.
Enums
- BTree
V2Record - A record from a B-tree v2.
Functions
- collect_
btree_ v2_ records - Collect all records from a B-tree v2 by traversing from the root.