pub struct ChunkCache { /* private fields */ }Expand description
LRU cache for decompressed chunks.
Thread-safe via parking_lot::Mutex (non-poisoning). Values are
Arc<Vec<u8>> so multiple readers can share the same decompressed chunk data.
Implementations
Sourceimpl ChunkCache
impl ChunkCache
Sourcepub fn new(max_bytes: usize, max_slots: usize) -> Self
pub fn new(max_bytes: usize, max_slots: usize) -> Self
Create a new chunk cache.
max_bytes: maximum total bytes of decompressed data to cache (default 64 MiB)max_slots: maximum number of entries (default 521)