pub struct FilterRegistry { /* private fields */ }Expand description
A registry of filter implementations.
Comes pre-loaded with deflate, shuffle, and fletcher32. Users can register additional filters (e.g., Blosc, LZ4, ZFP) before reading datasets.
Implementations
Sourceimpl FilterRegistry
impl FilterRegistry
Sourcepub fn register(&mut self, id: u16, f: FilterFn)
pub fn register(&mut self, id: u16, f: FilterFn)
Register a custom filter implementation for the given filter ID.
Overwrites any previously registered filter with the same ID.
Sourcepub fn apply(
&self,
filter: &FilterDescription,
data: &[u8],
element_size: usize,
) -> Result<Vec<u8>>
pub fn apply( &self, filter: &FilterDescription, data: &[u8], element_size: usize, ) -> Result<Vec<u8>>
Apply a single filter by ID.
Sourcepub fn apply_with_limit(
&self,
filter: &FilterDescription,
data: &[u8],
element_size: usize,
max_output_len: Option<usize>,
) -> Result<Vec<u8>>
pub fn apply_with_limit( &self, filter: &FilterDescription, data: &[u8], element_size: usize, max_output_len: Option<usize>, ) -> Result<Vec<u8>>
Apply a single filter by ID, passing a maximum decoded output length to built-in filters that can enforce it while decoding.