HDF5 Attribute message (type 0x000C).
Attributes are small named data items attached to any HDF5 object. Each attribute has a name, datatype, dataspace, and raw data.
Structs
- Attribute
Message - Parsed attribute message.
Functions
- parse
- Parse an attribute message.