pub fn parse(
cursor: &mut Cursor<'_>,
msg_size: usize,
) -> Result<DatatypeMessage>Expand description
Parse a datatype message starting at the current cursor position.
The msg_size is the total number of bytes allocated for this message
(used to skip any trailing padding).