HDF5 Object Header parser (v1 and v2).
Object headers contain a collection of header messages that describe an HDF5 object (group, dataset, committed datatype, etc.). Two on-disk formats exist:
- Version 1 (HDF5 < 1.8) — 16-byte fixed prefix, messages each have an 8-byte envelope (type u16 + size u16 + flags u8 + reserved 3).
- Version 2 (HDF5 >= 1.8) — begins with the
OHDRsignature, variable- length prefix, messages have a 4-or-6-byte envelope, and every chunk is checksummed with Jenkins lookup3.
Continuation messages (type 0x0010) cause the parser to follow an offset
to an additional chunk of messages (an OCHK block in v2, or a raw message
run in v1).
Structs
- Object
Header - Parsed object header with all its messages.