Structs
- Block
Cache Stats - Point-in-time statistics for
BlockCacheStorage. - Block
Cache Storage - Block-aligned LRU cache for any random-access storage backend.
- Bytes
Storage - In-memory storage backed by owned bytes.
- File
Storage - File-backed storage that serves explicit byte ranges via positional reads.
- Mmap
Storage - In-memory storage backed by a read-only memory map.
- Range
Request Storage - Storage backed by a caller-provided byte-range reader.
- Storage
Buffer - An immutable byte range returned by a storage backend.
Traits
- Storage
- Random-access, immutable byte storage for HDF5 parsing and reads.